@@ -1,10 +1,10 @@
 # __init__.py
 
 # Define package-level variables
-PACKAGE_VERSION = "1.0.1"
+PACKAGE_VERSION = "1.0.4"
 
 # Import modules to make them accessible when the package is imported
-from . import input_handler
-from . import response_handler
+from .input_handler import get_input
+from .response_handler import response
 
 
